@@ -1,5 +1,3 @@
-sumna_slow <- function(v) sum(is.na(v))
-
 sumna <- function(v){
   if(any(class(v) %in% c("numeric", "character", "integer", "logical", "factor"))){
     if(any(class(v) == "numeric"))   nasum <- na_numeric(v)
@@ -8,7 +6,7 @@ sumna <- function(v){
     if(any(class(v) == "factor"))    nasum <- na_integer(v)
     if(any(class(v) == "logical"))   nasum <- na_logical(v)
   } else {
-    nasum <- sumna_slow(v)
+    nasum <- sum(is.na(v))
   }
   return(nasum)
 }
